pyniryo
=========

.. contents:: **Table of Contents**
    :backlinks: none

Installation
------------

PyNiryo is distributed on `PyPI <https://pypi.org>`_ as a universal
wheel and is available on Linux/macOS and Windows and supports
Python 2.7/3.5+

.. code-block:: bash

    $ pip install pyniryo

Documentation
-----------------

Full documentation is available at http://docs.niryo.com/dev/pyniryo

License
-------

PyNiryo is distributed under the terms of
`GNU General Public License v3.0 <https://choosealicense.com/licenses/gpl-3.0>`_
